@@ -2,7 +2,6 @@ import importlib
 from functools import lru_cache
 
 __DEPENDENCY_GROUPS = {
-    "rag": ["chromadb"],
     "security": ["semgrep", "depscan"],
     "notification": ["slack_sdk"],
 }
@@ -22,9 +21,5 @@ def import_with_dependency_group(name):
         raise ImportError(error_msg)
 
 
-def chromadb():
-    return import_with_dependency_group("chromadb")
-
-
 def slack_sdk():
     return import_with_dependency_group("slack_sdk")
